---
title: <span class="badge object-type-scalar"></span> BytesPerSecondSI
---
# <span class="badge object-type-scalar"></span> BytesPerSecondSI

Data rate: bytes/sec(SI)

## Definition

```python
# Data rate: bytes/sec(SI)
BytesPerSecondSI: typing.Literal["Bps"] = "Bps"
```
